@@ -19,9 +19,8 @@ import ipywidgets as widgets
 
 # Establece las variables globales
 # Código HTML para la pestaña de instrucciones 
-instructions_html = None 
-with open('instructions.html', 'r') as file:
-    instructions_html = file.read()
+#instructions_html = None 
+
 
 __DEBUG__ = False
 
@@ -1602,12 +1601,7 @@ def CVOperacion(operacion):
 # Autor: Carlos Alberto Trujillo
 def PresentarInterfaz():
     # Define las pestañas
-    instructions_tab = widgets.HTMLMath(
-        value=instructions_html,
-        placeholder='',
-        description='',
-    )
-
+   
     basicas_tab = widgets.Output()
 
     with basicas_tab:        
@@ -1660,7 +1654,7 @@ def PresentarInterfaz():
         interact(CVOperacion,operacion=dd_oper)    
 
     interface_tabs = widgets.Tab(
-        children=[instructions_tab,basicas_tab,calculo_tab,algebra_tab, stats_tab, cvect_tab], _titles=tab_dict)
+        children=[basicas_tab,calculo_tab,algebra_tab, stats_tab, cvect_tab], _titles=tab_dict)
 
     return interface_tabs
 
